@@ -80,4 +80,10 @@ BuildOptionFrame(void);
 void
 BuildBandwidthFrame(void);
 
+void
+BuildSeviceTreeFrame(void);
+
+void
+BuildRegisterAccessFrame(void);
+
 #endif // __BUILDFRAMES_H__
