@@ -27,11 +27,8 @@ typedef struct
   int                     cancel_req;
 
   int v4l_dev;
-  unsigned char *v4l_buffer;
-  char v4l_dev_name[STRING_SIZE];
-
-  int period;
-  //int counter;
+  dc1394video_frame_t frame;
+  //unsigned char *v4l_buffer;
 
   struct video_capability vid_caps;
   struct video_window vid_win;
@@ -42,9 +39,6 @@ typedef struct
 gint
 V4lStartThread(camera_t* cam);
 
-void*
-V4lCleanupThread(void* arg);
-
 void*
 V4lThread(void* arg);
 
